searchData={"items":[{"type":"behaviour","title":"ElixirExt.Registry","doc":"The ElixirExt.Registry module is used to define the behaviour that is necessary to be qualified as a `RegMod` for name registration of processes.\n\nThe definition according to the Elixir Docs (found [here](https://hexdocs.pm/elixir/GenServer.html#module-name-registration)) is as follows:\n> The :via option expects a module that exports register_name/2, unregister_name/1, whereis_name/1 and send/2.\n> One such example is the :global module which uses these functions for keeping the list of names of processes and their associated PIDs that are available globally for a network of Elixir nodes.\n> Elixir also ships with a local, decentralized and scalable registry called Registry for locally storing names that are generated dynamically.\n\nThe definition according to the Erlang Docs (found [here](https://www.erlang.org/doc/man/gen_server.html#type-server_name)) is similar:\n> Register the gen_server process with the registry represented by RegMod.\n> The RegMod callback is to export the functions register_name/2, unregister_name/1, whereis_name/1, and send/2, which are to behave like the corresponding functions in global.\n> Thus, {via,global,GlobalName} is a valid reference equivalent to {global,GlobalName}.\n\nThe following callbacks and typespecs are copied over from the global registry definitions in order to ensure that we have the typespecs as maintained by Erlang's global.","ref":"ElixirExt.Registry.html"},{"type":"callback","title":"ElixirExt.Registry.register_name/2","doc":"","ref":"ElixirExt.Registry.html#c:register_name/2"},{"type":"callback","title":"ElixirExt.Registry.send/2","doc":"","ref":"ElixirExt.Registry.html#c:send/2"},{"type":"callback","title":"ElixirExt.Registry.unregister_name/1","doc":"","ref":"ElixirExt.Registry.html#c:unregister_name/1"},{"type":"callback","title":"ElixirExt.Registry.whereis_name/1","doc":"","ref":"ElixirExt.Registry.html#c:whereis_name/1"},{"type":"module","title":"Example","doc":"","ref":"Example.html"},{"type":"function","title":"Example.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Example.html#child_spec/1"},{"type":"function","title":"Example.hello/1","doc":"","ref":"Example.html#hello/1"},{"type":"function","title":"Example.registered_name/1","doc":"","ref":"Example.html#registered_name/1"},{"type":"function","title":"Example.start_link/1","doc":"","ref":"Example.html#start_link/1"},{"type":"function","title":"Example.whereis/1","doc":"","ref":"Example.html#whereis/1"},{"type":"module","title":"Reginald","doc":"Reginald is a simple distributed registry built on top of the built-in Erlang `:pg` module.\n\nThis module provides the public API of Reginald, while the internal modules provide the actual implementations.","ref":"Reginald.html"},{"type":"function","title":"Reginald.child_spec/1","doc":"","ref":"Reginald.html#child_spec/1"},{"type":"function","title":"Reginald.register_name/2","doc":"","ref":"Reginald.html#register_name/2"},{"type":"function","title":"Reginald.send/2","doc":"","ref":"Reginald.html#send/2"},{"type":"function","title":"Reginald.start_link/1","doc":"","ref":"Reginald.html#start_link/1"},{"type":"function","title":"Reginald.unregister_name/1","doc":"","ref":"Reginald.html#unregister_name/1"},{"type":"function","title":"Reginald.whereis_name/1","doc":"","ref":"Reginald.html#whereis_name/1"},{"type":"type","title":"Reginald.reg_mod/0","doc":"","ref":"Reginald.html#t:reg_mod/0"},{"type":"extras","title":"Reginald","doc":"# Reginald\n\n**TODO: Add description**","ref":"readme.html"},{"type":"extras","title":"Installation - Reginald","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `reginald` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:reginald, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Changelog","doc":"# Changelog\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [Unreleased]\n#","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Added new features\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Changed an existing functionality\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Deprecated - Changelog","doc":"- Deprecated a feature so that it can be removed in a later release\n\n#","ref":"changelog.html#deprecated"},{"type":"extras","title":"Removed - Changelog","doc":"- Removed a feature\n\n#","ref":"changelog.html#removed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fixed a bugfix\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Security - Changelog","doc":"- Patched a security vulnerability\n\n[Unreleased]: https://github.com/probably-not/reginald/compare/v0.1.0...HEAD\n[0.1.0]: https://github.com/probably-not/reginald/releases/tag/v0.1.0","ref":"changelog.html#security"}],"content_type":"text/markdown"}